# pds.api-client
Registry API enabling advanced search on PDS data and metadata. The API provides end-points to search for bundles, collections and any PDS products with advanced search queries. It also enables to browse the archive hierarchically downward (e.g. collection/s products) or upward (e.g. bundles containing a product).
The detailed syntax for querying the end-point is given in the reference documentation.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.1
- Package version: 1.2.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python &gt;&#x3D;3.7

## Migration from other generators like python and python-legacy

### Changes
1. This generator uses spec case for all (object) property names and parameter names.
    - So if the spec has a property name like camelCase, it will use camelCase rather than camel_case
    - So you will need to update how you input and read properties to use spec case
2. Endpoint parameters are stored in dictionaries to prevent collisions (explanation below)
    - So you will need to update how you pass data in to endpoints
3. Endpoint responses now include the original response, the deserialized response body, and (todo)the deserialized headers
    - So you will need to update your code to use response.body to access deserialized data
4. All validated data is instantiated in an instance that subclasses all validated Schema classes and Decimal/str/list/tuple/frozendict/NoneClass/BoolClass/bytes/io.FileIO
    - This means that you can use isinstance to check if a payload validated against a schema class
    - This means that no data will be of type None/True/False
        - ingested None will subclass NoneClass
        - ingested True will subclass BoolClass
        - ingested False will subclass BoolClass
        - So if you need to check is True/False/None, instead use instance.is_true_oapg()/.is_false_oapg()/.is_none_oapg()
5. All validated class instances are immutable except for ones based on io.File
    - This is because if properties were changed after validation, that validation would no longer apply
    - So no changing values or property values after a class has been instantiated
6. String + Number types with formats
    - String type data is stored as a string and if you need to access types based on its format like date,
    date-time, uuid, number etc then you will need to use accessor functions on the instance
    - type string + format: See .as_date_oapg, .as_datetime_oapg, .as_decimal_oapg, .as_uuid_oapg
    - type number + format: See .as_float_oapg, .as_int_oapg
    - this was done because openapi/json-schema defines constraints. string data may be type string with no format
    keyword in one schema, and include a format constraint in another schema
    - So if you need to access a string format based type, use as_date_oapg/as_datetime_oapg/as_decimal_oapg/as_uuid_oapg
    - So if you need to access a number format based type, use as_int_oapg/as_float_oapg
7. Property access on AnyType(type unset) or object(dict) schemas
    - Only required keys with valid python names are properties like .someProp and have type hints
    - All optional keys may not exist, so properties are not defined for them
    - One can access optional values with dict_instance['optionalProp'] and KeyError will be raised if it does not exist
    - Use get_item_oapg if you need a way to always get a value whether or not the key exists
        - If the key does not exist, schemas.unset is returned from calling dict_instance.get_item_oapg('optionalProp')
        - All required and optional keys have type hints for this method, and @typing.overload is used
        - A type hint is also generated for additionalProperties accessed using this method
    - So you will need to update you code to use some_instance['optionalProp'] to access optional property
    and additionalProperty values
8. The location of the api classes has changed
    - Api classes are located in your_package.apis.tags.some_api
    - This change was made to eliminate redundant code generation
    - Legacy generators generated the same endpoint twice if it had > 1 tag on it
    - This generator defines an endpoint in one class, then inherits that class to generate
      apis by tags and by paths
    - This change reduces code and allows quicker run time if you use the path apis
        - path apis are at your_package.apis.paths.some_path
    - Those apis will only load their needed models, which is less to load than all of the resources needed in a tag api
    - So you will need to update your import paths to the api classes

### Why are Oapg and _oapg used in class and method names?
Classes can have arbitrarily named properties set on them
Endpoints can have arbitrary operationId method names set
For those reasons, I use the prefix Oapg and _oapg to greatly reduce the likelihood of collisions
on protected + public classes/methods.
oapg stands for OpenApi Python Generator.

### Object property spec case
This was done because when payloads are ingested, they can be validated against N number of schemas.
If the input signature used a different property name then that has mutated the payload.
So SchemaA and SchemaB must both see the camelCase spec named variable.
Also it is possible to send in two properties, named camelCase and camel_case in the same payload.
That use case should be support so spec case is used.

### Parameter spec case
Parameters can be included in different locations including:
- query
- path
- header
- cookie

Any of those parameters could use the same parameter names, so if every parameter
was included as an endpoint parameter in a function signature, they would collide.
For that reason, each of those inputs have been separated out into separate typed dictionaries:
- query_params
- path_params
- header_params
- cookie_params

So when updating your code, you will need to pass endpoint parameters in using those
dictionaries.

### Endpoint responses
Endpoint responses have been enriched to now include more information.
Any response reom an endpoint will now include the following properties:
response: urllib3.HTTPResponse
body: typing.Union[Unset, Schema]
headers: typing.Union[Unset, TODO]
Note: response header deserialization has not yet been added


## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import pds.api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pds.api_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import pds.api_client
from pprint import pprint
from pds.api_client.apis.tags import classes_api
from pds.api_client.model.error_message import ErrorMessage
from pds.api_client.model.pds4_products import Pds4Products
from pds.api_client.model.pds_products import PdsProducts
from pds.api_client.model.wyriwyg_products import WyriwygProducts
# Defining the host is optional and defaults to https://pds.nasa.gov/api/registry/1.0
# See configuration.py for a list of all supported configuration parameters.
configuration = pds.api_client.Configuration(
    host = "https://pds.nasa.gov/api/registry/1.0"
)


# Enter a context with an instance of the API client
with pds.api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = classes_api.ClassesApi(api_client)
    _class = "any" # str | syntax: one of the allowable enum values  This is a shortcut for doing a query with ... 
fields = [
        "fields_example"
    ] # [str] | syntax: fields=field1,field2,...  behavior: this parameter and the headder Accept: type determine what content is packaged for the result. While the types application/csv, application/kvp+json, and text/csv return only the fields requesteted, all of the other types have a minimal set of fields that must be returned. Duplicating a minimally required field in this parameter has not effect. The types vnd.nasa.pds.pds4+json and vnd.nasa.pds.pds4+xml have a complete set of fields that must be returned; meaning this parameter does not impact their content. When fields is not used, then the minimal set of fields, or all when minimal is an empty set, is returned.  notes: the blob fields are blocked unless specifically requrested and only for the */csv and application/kvp+csv types.  (optional)
keywords = [
        "keywords_example"
    ] # [str] | syntax: keyword=keyword1,keyword2,...  behavior: free text search on title and description (if set q is ignored  (optional)
limit = 100 # int | syntax: limit=10  behavior: maximum number of matching results returned, for pagination  note: limit=0 returns just the summary  (optional) (default to CodegenParameter{isFormParam=false, isQueryParam=true, isPathParam=false, isHeaderParam=false, isCookieParam=false, isBodyParam=false, isContainer=false, isCollectionFormatMulti=false, isPrimitiveType=true, isModel=false, isExplode=true, baseName='limit', paramName='limit', dataType='int', datatypeWithEnum='null', dataFormat='null', collectionFormat='null', description='syntax: limit=10  behavior: maximum number of matching results returned, for pagination  note: limit=0 returns just the summary ', unescapedDescription='syntax: limit=10

behavior: maximum number of matching results returned, for pagination

note: limit=0 returns just the summary
', baseType='null', defaultValue='100', enumDefaultValue='null', enumName='null', style='FORM', deepObject='false', allowEmptyValue='false', example='100', jsonSchema='{
  "name" : "limit",
  "in" : "query",
  "description" : "syntax: limit=10\n\nbehavior: maximum number of matching results returned, for pagination\n\nnote: limit=0 returns just the summary\n",
  "required" : false,
  "style" : "form",
  "explode" : true,
  "schema" : {
    "minimum" : 0,
    "type" : "integer",
    "default" : 100
  }
}', isString=false, isNumeric=false, isInteger=true, isShort=false, isLong=false, isUnboundedInteger=true, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isAnyType=false, isArray=false, isMap=false, isFile=false, isEnum=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, additionalProperties=null, vars=[], requiredVars=[], vendorExtensions={}, hasValidation=true, maxProperties=null, minProperties=null, isNullable=false, isDeprecated=false, required=false, maximum='null', exclusiveMaximum=false, minimum='0', exclusiveMinimum=false, maxLength=null, minLength=null, pattern='null', maxItems=null, minItems=null, uniqueItems=false, uniqueItemsBoolean=null, contentType=null, multipleOf=null, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, schema=CodegenProperty{openApiType='integer', baseName='LimitSchema', complexType='null', getter='getLimit', setter='setLimit', description='null', dataType='int', datatypeWithEnum='int', dataFormat='null', name='limit', min='null', max='null', defaultValue='100', defaultValueWithParam=' = data.limit;', baseType='int', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='100', jsonSchema='{
  "minimum" : 0,
  "type" : "integer",
  "default" : 100
}', minimum='0', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, required=false, deprecated=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=false, isInteger=true, isShort=false, isLong=false, isUnboundedInteger=true, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isArray=false, isMap=false, isEnum=false, isInnerEnum=false, isEnumRef=false, isAnyType=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, isDiscriminator=false, _enum=null, allowableValues=null, items=null, additionalProperties=null, vars=[], requiredVars=[], mostInnerItems=null, vendorExtensions={}, hasValidation=true, isInherited=false, discriminatorValue='null', nameInCamelCase='Limit', nameInSnakeCase='null', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, uniqueItemsBoolean=null, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false, isBooleanSchemaTrue=false, isBooleanSchemaFalse=false, format=null, dependentRequired=null, contains=null}, content=null, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false})
q = "q_example" # str | syntax: q=\"vid eq 13.0\"  behavior: query uses eq,ne,gt,ge,lt,le,(,),not,and,or operators. Properties are named as in 'properties' attributes, literals are strings between quotes, like \"animal\", or numbers. Detailed query specification is available at https://bit.ly/3h3D54T  note: ignored when keyword is present  (optional)
sort = [
        "sort_example"
    ] # [str] | syntax: sort=asc(field0),desc(field1),...  behavior: is this implemented?  (optional)
start = 0 # int | syntax: start=12  behavior: offset in matching result list, for pagination  (optional) (default to CodegenParameter{isFormParam=false, isQueryParam=true, isPathParam=false, isHeaderParam=false, isCookieParam=false, isBodyParam=false, isContainer=false, isCollectionFormatMulti=false, isPrimitiveType=true, isModel=false, isExplode=true, baseName='start', paramName='start', dataType='int', datatypeWithEnum='null', dataFormat='null', collectionFormat='null', description='syntax: start=12  behavior: offset in matching result list, for pagination ', unescapedDescription='syntax: start=12

behavior: offset in matching result list, for pagination
', baseType='null', defaultValue='0', enumDefaultValue='null', enumName='null', style='FORM', deepObject='false', allowEmptyValue='false', example='0', jsonSchema='{
  "name" : "start",
  "in" : "query",
  "description" : "syntax: start=12\n\nbehavior: offset in matching result list, for pagination\n",
  "required" : false,
  "style" : "form",
  "explode" : true,
  "schema" : {
    "minimum" : 0,
    "type" : "integer",
    "default" : 0
  }
}', isString=false, isNumeric=false, isInteger=true, isShort=false, isLong=false, isUnboundedInteger=true, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isAnyType=false, isArray=false, isMap=false, isFile=false, isEnum=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, additionalProperties=null, vars=[], requiredVars=[], vendorExtensions={}, hasValidation=true, maxProperties=null, minProperties=null, isNullable=false, isDeprecated=false, required=false, maximum='null', exclusiveMaximum=false, minimum='0', exclusiveMinimum=false, maxLength=null, minLength=null, pattern='null', maxItems=null, minItems=null, uniqueItems=false, uniqueItemsBoolean=null, contentType=null, multipleOf=null, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, schema=CodegenProperty{openApiType='integer', baseName='StartSchema', complexType='null', getter='getStart', setter='setStart', description='null', dataType='int', datatypeWithEnum='int', dataFormat='null', name='start', min='null', max='null', defaultValue='0', defaultValueWithParam=' = data.start;', baseType='int', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='0', jsonSchema='{
  "minimum" : 0,
  "type" : "integer",
  "default" : 0
}', minimum='0', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, required=false, deprecated=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=false, isInteger=true, isShort=false, isLong=false, isUnboundedInteger=true, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isArray=false, isMap=false, isEnum=false, isInnerEnum=false, isEnumRef=false, isAnyType=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, isDiscriminator=false, _enum=null, allowableValues=null, items=null, additionalProperties=null, vars=[], requiredVars=[], mostInnerItems=null, vendorExtensions={}, hasValidation=true, isInherited=false, discriminatorValue='null', nameInCamelCase='Start', nameInSnakeCase='null', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, uniqueItemsBoolean=null, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false, isBooleanSchemaTrue=false, isBooleanSchemaFalse=false, format=null, dependentRequired=null, contains=null}, content=null, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false})

    try:
        # returns all PDS products of the given PDS product class that meet all given constraints. 
        api_response = api_instance.class_list(_classfields=fieldskeywords=keywordslimit=limitq=qsort=sortstart=start)
        pprint(api_response)
    except pds.api_client.ApiException as e:
        print("Exception when calling ClassesApi->class_list: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://pds.nasa.gov/api/registry/1.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ClassesApi* | [**class_list**](docs/apis/tags/ClassesApi.md#class_list) | **get** /classes/{class} | returns all PDS products of the given PDS product class that meet all given constraints. 
*ClassesApi* | [**classes**](docs/apis/tags/ClassesApi.md#classes) | **get** /classes | returns a list of the available PDS product class at this API. This is not all of the PDS product class available in the database, but simply the names that can be used in the /classes/{class} endpoints. 
*DeprecatedApi* | [**bundle_list**](docs/apis/tags/DeprecatedApi.md#bundle_list) | **get** /bundles | deprecated
*DeprecatedApi* | [**bundles_lidvid**](docs/apis/tags/DeprecatedApi.md#bundles_lidvid) | **get** /bundles/{identifier} | deprecated
*DeprecatedApi* | [**bundles_lidvid_all**](docs/apis/tags/DeprecatedApi.md#bundles_lidvid_all) | **get** /bundles/{identifier}/all | deprecated
*DeprecatedApi* | [**bundles_lidvid_collections**](docs/apis/tags/DeprecatedApi.md#bundles_lidvid_collections) | **get** /bundles/{identifier}/collections | deprecated
*DeprecatedApi* | [**bundles_lidvid_collections_all**](docs/apis/tags/DeprecatedApi.md#bundles_lidvid_collections_all) | **get** /bundles/{identifier}/collections/all | deprecated
*DeprecatedApi* | [**bundles_lidvid_collections_latest**](docs/apis/tags/DeprecatedApi.md#bundles_lidvid_collections_latest) | **get** /bundles/{identifier}/collections/latest | deprecated
*DeprecatedApi* | [**bundles_lidvid_latest**](docs/apis/tags/DeprecatedApi.md#bundles_lidvid_latest) | **get** /bundles/{identifier}/latest | deprecated
*DeprecatedApi* | [**bundles_lidvid_products**](docs/apis/tags/DeprecatedApi.md#bundles_lidvid_products) | **get** /bundles/{identifier}/products | deprecated
*DeprecatedApi* | [**collection_list**](docs/apis/tags/DeprecatedApi.md#collection_list) | **get** /collections | deprecated
*DeprecatedApi* | [**collections_lidvid**](docs/apis/tags/DeprecatedApi.md#collections_lidvid) | **get** /collections/{identifier} | deprecated
*DeprecatedApi* | [**collections_lidvid_all**](docs/apis/tags/DeprecatedApi.md#collections_lidvid_all) | **get** /collections/{identifier}/all | deprecated
*DeprecatedApi* | [**collections_lidvid_bundles**](docs/apis/tags/DeprecatedApi.md#collections_lidvid_bundles) | **get** /collections/{identifier}/bundles | deprecated
*DeprecatedApi* | [**collections_lidvid_latest**](docs/apis/tags/DeprecatedApi.md#collections_lidvid_latest) | **get** /collections/{identifier}/latest | deprecated
*DeprecatedApi* | [**collections_lidvid_products**](docs/apis/tags/DeprecatedApi.md#collections_lidvid_products) | **get** /collections/{identifier}/products | deprecated
*DeprecatedApi* | [**collections_lidvid_products_all**](docs/apis/tags/DeprecatedApi.md#collections_lidvid_products_all) | **get** /collections/{identifier}/products/all | deprecated
*DeprecatedApi* | [**collections_lidvid_products_latest**](docs/apis/tags/DeprecatedApi.md#collections_lidvid_products_latest) | **get** /collections/{identifier}/products/latest | deprecated
*DeprecatedApi* | [**products_lidivid_bundles_all**](docs/apis/tags/DeprecatedApi.md#products_lidivid_bundles_all) | **get** /products/{identifier}/bundles/all | deprecated
*DeprecatedApi* | [**products_lidvid_bundles**](docs/apis/tags/DeprecatedApi.md#products_lidvid_bundles) | **get** /products/{identifier}/bundles | deprecated
*DeprecatedApi* | [**products_lidvid_bundles_latest**](docs/apis/tags/DeprecatedApi.md#products_lidvid_bundles_latest) | **get** /products/{identifier}/bundles/latest | deprecated
*DeprecatedApi* | [**products_lidvid_collections**](docs/apis/tags/DeprecatedApi.md#products_lidvid_collections) | **get** /products/{identifier}/collections | deprecated
*DeprecatedApi* | [**products_lidvid_collections_all**](docs/apis/tags/DeprecatedApi.md#products_lidvid_collections_all) | **get** /products/{identifier}/collections/all | deprecated
*DeprecatedApi* | [**products_lidvid_collections_latest**](docs/apis/tags/DeprecatedApi.md#products_lidvid_collections_latest) | **get** /products/{identifier}/collections/latest | deprecated
*ProductsApi* | [**product_list**](docs/apis/tags/ProductsApi.md#product_list) | **get** /products | returns all PDS data products, including bundles, collections, documentation, context and observational products taht meet all given constraints. 
*ProductsApi* | [**select_by_lidvid**](docs/apis/tags/ProductsApi.md#select_by_lidvid) | **get** /products/{identifier} | returns one PDS Product with the identifier selected from all PDS Products, including bundles, collections, data, documentation, context and observational products. See identifier for details on how it determines what is returned. 
*ProductsApi* | [**select_by_lidvid_all**](docs/apis/tags/ProductsApi.md#select_by_lidvid_all) | **get** /products/{identifier}/all | returns all product versions with the identifier (lid) selected from all PDS Products. See identifier for details on how it determines what is returned.  note: if given a lidvid, it will be translated to a lid 
*ProductsApi* | [**select_by_lidvid_latest**](docs/apis/tags/ProductsApi.md#select_by_lidvid_latest) | **get** /products/{identifier}/latest | returns one PDS Product with the identifier selected from all PDS Products. See identifier for details on how it determines what is returned. 
*ReferencesApi* | [**class_member_of**](docs/apis/tags/ReferencesApi.md#class_member_of) | **get** /classes/{class}/{identifier}/member-of | returns one or more PDS Products that have the given PDS product class and lid/lidvid as a member. 
*ReferencesApi* | [**class_member_of_of**](docs/apis/tags/ReferencesApi.md#class_member_of_of) | **get** /classes/{class}/{identifier}/member-of/member-of | returns one or more PDS Products that have the given PDS product class and lid/lidvid as a member of its members. 
*ReferencesApi* | [**class_member_of_of_vers**](docs/apis/tags/ReferencesApi.md#class_member_of_of_vers) | **get** /classes/{class}/{identifier}/member-of/member-of/{versions} | returns one or more PDS Products that have the given PDS product class and lid/lidvid as a member of its members. 
*ReferencesApi* | [**class_member_of_vers**](docs/apis/tags/ReferencesApi.md#class_member_of_vers) | **get** /classes/{class}/{identifier}/member-of/{versions} | returns one or more PDS Products that have the given PDS product class and lid/lidvid as a member. 
*ReferencesApi* | [**class_members**](docs/apis/tags/ReferencesApi.md#class_members) | **get** /classes/{class}/{identifier}/members | returns one or more PDS Products that are members of the given PDS product class and lid/lidvid. 
*ReferencesApi* | [**class_members_members**](docs/apis/tags/ReferencesApi.md#class_members_members) | **get** /classes/{class}/{identifier}/members/members | returns one or more PDS Products that are the members of the members of the given PDS product class and lid/lidvid. 
*ReferencesApi* | [**class_members_members_vers**](docs/apis/tags/ReferencesApi.md#class_members_members_vers) | **get** /classes/{class}/{identifier}/members/members/{versions} | returns one or more PDS Products that are the members of the members of the given PDS product class and lid/lidvid. 
*ReferencesApi* | [**class_members_vers**](docs/apis/tags/ReferencesApi.md#class_members_vers) | **get** /classes/{class}/{identifier}/members/{versions} | returns one or more PDS Products that are members of the given PDS product class and lid/lidvid. 
*ReferencesApi* | [**product_member_of**](docs/apis/tags/ReferencesApi.md#product_member_of) | **get** /products/{identifier}/member-of | returns one or more PDS Products that have the given PDS lid/lidvid as a member. 
*ReferencesApi* | [**product_member_of_of**](docs/apis/tags/ReferencesApi.md#product_member_of_of) | **get** /products/{identifier}/member-of/member-of | returns one or more PDS Products that have the given PDS lid/lidvid as a member of its members. 
*ReferencesApi* | [**product_member_of_of_vers**](docs/apis/tags/ReferencesApi.md#product_member_of_of_vers) | **get** /products/{identifier}/member-of/member-of/{versions} | returns one or more PDS Products that have the given PDS lid/lidvid as a member of its members. 
*ReferencesApi* | [**product_member_of_vers**](docs/apis/tags/ReferencesApi.md#product_member_of_vers) | **get** /products/{identifier}/member-of/{versions} | returns one or more PDS Products that have the given PDS lid/lidvid as a member. 
*ReferencesApi* | [**product_members**](docs/apis/tags/ReferencesApi.md#product_members) | **get** /products/{identifier}/members | returns all of the members of the given lid/lidvid 
*ReferencesApi* | [**product_members_members**](docs/apis/tags/ReferencesApi.md#product_members_members) | **get** /products/{identifier}/members/members | returns all of the members of the members of the given lid/lidvid 
*ReferencesApi* | [**product_members_members_vers**](docs/apis/tags/ReferencesApi.md#product_members_members_vers) | **get** /products/{identifier}/members/members/{versions} | returns all of the members of the members of the given lid/lidvid 
*ReferencesApi* | [**product_members_vers**](docs/apis/tags/ReferencesApi.md#product_members_vers) | **get** /products/{identifier}/members/{versions} | returns all of the members of the given lid/lidvid 

## Documentation For Models

 - [ErrorMessage](docs/models/ErrorMessage.md)
 - [Metadata](docs/models/Metadata.md)
 - [Pds4Metadata](docs/models/Pds4Metadata.md)
 - [Pds4Product](docs/models/Pds4Product.md)
 - [Pds4Products](docs/models/Pds4Products.md)
 - [PdsProduct](docs/models/PdsProduct.md)
 - [PdsProducts](docs/models/PdsProducts.md)
 - [PropertyArrayValues](docs/models/PropertyArrayValues.md)
 - [Reference](docs/models/Reference.md)
 - [Summary](docs/models/Summary.md)
 - [WyriwygProduct](docs/models/WyriwygProduct.md)
 - [WyriwygProducts](docs/models/WyriwygProducts.md)

## Documentation For Authorization

 All endpoints do not require authorization.

## Author

pds-operator@jpl.nasa.gov
pds-operator@jpl.nasa.gov
pds-operator@jpl.nasa.gov
pds-operator@jpl.nasa.gov

## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in pds.api_client.apis and pds.api_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from pds.api_client.apis.default_api import DefaultApi`
- `from pds.api_client.model.pet import Pet`

Solution 1:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import pds.api_client
from pds.api_client.apis import *
from pds.api_client.models import *
```
